from Tkinter import *
import sys
from zope import component

import interfaces
import components

class CurrencyConverterApp:

    def __init__(self, root):

        # get a list of target currencies
        u = components.USDCurrency(None)
        currencies = [c.currency_symbol() for c in
                      component.subscribers([u], interfaces.ICurrency)]
        
        # create the main window
        frame = Frame(root)
        frame.pack()

        # input widgets
        lblInput = Label(frame, text="Value (US$): ").grid(row=0)
        self.txtInput = Entry(frame)
        self.txtInput.grid(row=0, column=1)

        # target currency select
        lblCurrency = Label(frame, text="Target Currency: ").grid(row=1)
        self.lstTargets = Listbox(frame)
        for c in currencies:
            self.lstTargets.insert(END, c)
        self.lstTargets.grid(row=1,column=1)
        
        # output widgets
        lblOutput = Label(frame,
                          text='Converted Value:').grid(row=2)
        self.txtOutput = Entry(frame)
        self.txtOutput.grid(row=2, column=1)
        
        # command buttons
        Button(frame, text="Convert", command=self.convert).grid(row=3)
        Button(frame, text="Exit",    command=self.quit).grid(row=3, column=1)

    def convert(self):

        # clear the output widget
        self.txtOutput.delete(0,END)

        # convert from US$ to target
        usd = components.USDCurrency(float(self.txtInput.get()))
        target = self.lstTargets.get(self.lstTargets.curselection()[0])

        # look up the converter by target name
        converter = component.queryAdapter(usd, interfaces.IConverter, target)
        self.txtOutput.insert(END, converter.convert())

    def quit(self):

        sys.exit()
    
if __name__ == '__main__':
    root = Tk()
    app = CurrencyConverterApp(root)

    root.mainloop()
    

    
